import { queryOMDb } from "@/api/omdb";
import { INextJsProps, stringifyQueryParams } from "../Search/page";
import ImgCard from "@/components/ImgCard";

export default async ({ searchParams }: INextJsProps) => {
  const movie = await queryOMDb(stringifyQueryParams(searchParams!));
  const { Poster, Ratings, ...rest } = movie;
  return (
    <div className="rounded p-4  bg-gray-300 w-auto mx-4 flex-column">
      <ImgCard
        width={400}
        height={580}
        src={movie.Poster !== "N/A" ? movie.Poster : ""}
        alt={`${movie.Title} Movie Poster`}
      >
        <div className="mt-auto">
          <h3 className="mb-2 text-lg font-semibold">{movie.Title}</h3>
          {Object.entries(rest).map(([key, value]) => {
            return (
              <p key={key} className="mb-2 text-sm text-gray-700">
                <strong>{key}: </strong>
                {value as string}
              </p>
            );
          })}
          <h3>Ratings:</h3>
          <ul>
            {movie.Ratings.map((r: { Source: string; Value: string }) => (
              <li key={r.Source}>
                {r.Source} - {r.Value}
              </li>
            ))}
          </ul>
        </div>
      </ImgCard>
    </div>
  );
};
